@@ -1,4 +1,5 @@
 from django.contrib import admin
+from django.http import HttpRequest
 
 from ob_dj_otp.core.otp.models import OneTruePairing
 
@@ -16,5 +17,13 @@ class OneTruePairingAdmin(admin.ModelAdmin):
     )
     model = OneTruePairing
 
+    def has_add_permission(self, request: HttpRequest) -> bool:
+        return False
+
+    def has_change_permission(
+        self, request: HttpRequest, obj: OneTruePairing = None
+    ) -> bool:
+        return False
+
 
 admin.site.register(OneTruePairing, OneTruePairingAdmin)
