@@ -15,7 +15,10 @@ class OneTruePairingManager(models.Manager):
             # If OTP_FORCE_CODE not set, generate a 5 digit number
             # and store as string
             if not verification_code:
-                verification_code = randint(100000, 999999).__str__()
+                code_length = getattr(settings, "OTP_CODE_LENGTH", 5)
+                code_length_min = pow(10, code_length - 1)
+                code_length_max = pow(10, code_length) - 1
+                verification_code = randint(code_length_min, code_length_max).__str__()
 
             kwargs["verification_code"] = verification_code
 
